==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        varchar (  20 )                 NOT NULL            /*   1 振分条件     */
 , HOST         varchar ( 100 )                 NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         varchar (   6 )                                     /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         varchar (   6 )                                     /*   4 認証         */
 , AUTHUSER     varchar ( 100 )                                     /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     varchar ( 100 )                                     /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     varchar ( 500 )                                     /*   7 ｺﾒﾝﾄ         */
 , FGJ          varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar (  14 )                                     /* 820 登録日時     */
 , PGSET        varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET       varchar (  10 )                                     /* 850 作成者       */
 , USRUPD       varchar (  10 )                                     /* 855 更新者       */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        varchar (  20 )                 NOT NULL            /*   1 振分条件     */
 , HOST         varchar ( 100 )                 NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         varchar (   6 )                                     /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         varchar (   6 )                                     /*   4 認証         */
 , AUTHUSER     varchar ( 100 )                                     /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     varchar ( 100 )                                     /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     varchar ( 500 )                                     /*   7 ｺﾒﾝﾄ         */
 , FGJ          varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar (  14 )                                     /* 820 作成日時     */
 , PGSET        varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET       varchar (  10 )                                     /* 850 作成者       */
 , USRUPD       varchar (  10 )                                     /* 855 更新者       */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG       */
);
